<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Status;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Database\Eloquent\Builder;

Table::make('event-delegate.index')
    ->tapQuery(function (Builder $query) {
        return $query->joinRelationship('user');
    })
    ->addAvailableColumns(function () {
        return [
            Text::make('ID')->name('identifier'),
            Text::make('First name'),
            Text::make('Last name'),
            Text::make('Email'),
            Text::make('Profession'),
            Status::make('Status')->options(\EventPortal\Domain\Util\Status::make('eventDelegate')->forFilters()),
        ];
    })
    ->addRowAction(function (Event $event, Delegate $delegate) {
        return ButtonDropdown::make('Manage delegate')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.delegate.show', [
                        'event' => $event->id,
                        'delegate' => $delegate->id,
                    ]),
            ]);
    });

Table::make('event-delegate.add')
    ->joinRelation('user')
    ->addAvailableColumns(function () {
        return [
            Text::make('ID')->name('identifier'),
            Text::make('First name'),
            Text::make('Last name'),
            Text::make('Email'),
            Text::make('Profession'),
        ];
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Add delegates to event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.delegate.store', [
                'event' => $event->id,
            ]);
    });
