<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class UserTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function has_computed_name()
    {
        $userFullName = factory(User::class)->create([
            'first_name' => 'Test',
            'last_name' => 'User',
        ]);

        $userNoFirstName = factory(User::class)->create([
            'first_name' => null,
            'last_name' => 'Lastname',
        ]);

        $userNoLastName = factory(User::class)->create([
            'first_name' => 'Firstname',
            'last_name' => null,
        ]);

        $this->assertDatabaseHas('users', [
            'first_name' => 'Test',
            'last_name' => 'User',
        ]);

        $this->assertEquals('Test User', $userFullName->full_name);
        $this->assertEquals('Lastname', $userNoFirstName->full_name);
        $this->assertEquals('Firstname', $userNoLastName->full_name);
    }

    /** @test **/
    public function returns_true_if_user_is_admin(): void
    {
        $admin = factory(Admin::class)->create();

        $this->assertTrue($admin->user->isAdmin());
    }

    /** @test **/
    public function returns_false_if_user_is_not_admin(): void
    {
        $user = factory(User::class)->create();

        $this->assertFalse($user->isAdmin());
    }
}
